@@ -25,32 +25,36 @@ from ..exceptions import UserError
 # which will break if they change the html structure of that page. Opted for the
 # hardcoding here for simplicity.
 region_to_location_map = {
-    'us-east-2': 'US East (Ohio)',
-    'us-east-1': 'US East (N. Virginia)',
-    'us-west-1': 'US West (N. California)',
-    'us-west-2': 'US West (Oregon)',
+    'af-south-1': 'Africa (Cape Town)',
     'ap-east-1': 'Asia Pacific (Hong Kong)',
-    'ap-south-1': 'Asia Pacific (Mumbai)',
-    'ap-northeast-3': 'Asia Pacific (Osaka-Local)',
+    'ap-northeast-1': 'Asia Pacific (Tokyo)',
     'ap-northeast-2': 'Asia Pacific (Seoul)',
+    'ap-northeast-3': 'Asia Pacific (Osaka)',
+    'ap-south-1': 'Asia Pacific (Mumbai)',
     'ap-southeast-1': 'Asia Pacific (Singapore)',
     'ap-southeast-2': 'Asia Pacific (Sydney)',
-    'ap-northeast-1': 'Asia Pacific (Tokyo)',
     'ca-central-1': 'Canada (Central)',
     'cn-north-1': 'China (Beijing)',
     'cn-northwest-1': 'China (Ningxia)',
     'eu-central-1': 'EU (Frankfurt)',
+    'eu-north-1': 'EU (Stockholm)',
+    'eu-south-1': 'EU (Milan)',
     'eu-west-1': 'EU (Ireland)',
     'eu-west-2': 'EU (London)',
     'eu-west-3': 'EU (Paris)',
-    'eu-north-1': 'EU (Stockholm)',
-    'sa-east-1': 'South America (Sao Paulo)',
     'me-south-1': 'Middle East (Bahrain)',
+    'sa-east-1': 'South America (Sao Paulo)',
+    'us-east-1': 'US East (N. Virginia)',
+    'us-east-2': 'US East (Ohio)',
+    'us-west-1': 'US West (N. California)',
+    'us-west-2': 'US West (Oregon)',
 }
 
 
 class EC2Provider(BaseProvider):
     username = 'admin'
+    alias = 'ec2'
+    default_size = 't3.micro'
 
     def __init__(self, aws_access_key_id, aws_secret_access_key, region=None):
         self.aws_access_key_id = aws_access_key_id
@@ -61,7 +65,7 @@ class EC2Provider(BaseProvider):
 
     @property
     def ec2(self):
-        # Construct this lazily to prevent it region from having to be
+        # Construct this lazily to prevent the region from having to be
         # specified to list regions or sizes
         if self._ec2:
             return self._ec2
@@ -117,8 +121,11 @@ class EC2Provider(BaseProvider):
             cloud_init,
             private_networking,
             tags,
-            size='t3.micro',
+            size=None,
             **kwargs):
+        if size is None:
+            size = self.default_size
+
         zone = kwargs.get('zone')
         if not zone:
             raise UserError('You must specify the ec2 availability zone')
@@ -137,12 +144,20 @@ class EC2Provider(BaseProvider):
         elif not subnets:
             raise UserError('No available subnets in %s' % zone)
         elif len(subnets) > 1:
+            subnet_summary = []
+            for subnet in subnets:
+                for tag in subnet.get('Tags', []):
+                    if tag['Key'] == 'Name':
+                        subnet_summary.append('%s (%s)' % (subnet['SubnetId'], tag['Value']))
+                        break
+                else:
+                    subnet_summary.append(subnet['SubnetId'])
             raise UserError('More than one subnet in availability zone, specify'
-                ' which one to use: %s' % (', '.join(s.id for s in subnets)))
+                ' which one to use: %s' % (', '.join(subnet_summary)))
 
         subnet = subnets[0]
         temp_security_group = self.create_temp_security_group(minion_id,
-            kwargs.get('connection_gateway'))
+            kwargs.get('connection_gateway'), subnet['VpcId'])
 
         block_devices = []
         volume_type = kwargs.get('volume_type')
@@ -201,7 +216,10 @@ class EC2Provider(BaseProvider):
         node = Node(id=instance['InstanceId'], name=minion_id, state=instance['State']['Name'],
             public_ips=[], private_ips=[instance['PrivateIpAddress']],
             driver=self.ec2, created_at=instance['LaunchTime'], extra=None)
-        return node, temp_security_group
+        return node, {
+            'groupId': temp_security_group,
+            'vpcId': subnet['VpcId'],
+        }
 
 
     def get_node(self, node):
@@ -240,7 +258,7 @@ class EC2Provider(BaseProvider):
             created_at=instance['LaunchTime'], extra=None)
 
 
-    def create_temp_security_group(self, minion_id, connection_gateway):
+    def create_temp_security_group(self, minion_id, connection_gateway, vpc_id):
         current_date = datetime.datetime.utcnow().strftime('%Y-%m-%dT%H-%M-%S')
         name = 'temp-for-%s-%s' % (minion_id, current_date)
 
@@ -258,6 +276,7 @@ class EC2Provider(BaseProvider):
         group = self.ec2.create_security_group(
             GroupName=name,
             Description='Temporary group for initial saltmaster ssh initialization',
+            VpcId=vpc_id,
         )
         group_id = group['GroupId']
 
@@ -295,20 +314,32 @@ class EC2Provider(BaseProvider):
         # Delete the temp security group that allowed ssh
         # Detach the security group from the instance. An instance must have at
         # least one security group, so we attach the VPC default group.
-        self.delete_node_security_group(hart_node.node, hart_node.node_extra)
+        self.delete_node_security_group(
+            hart_node.node,
+            hart_node.node_extra['groupId'],
+            hart_node.node_extra['vpcId'],
+        )
 
 
-    def delete_node_security_group(self, node, group_id):
-        print('Deleting temporary security group')
-        response = self.ec2.describe_security_groups(GroupNames=['default'])
+    def delete_node_security_group(self, node, group_id, vpc_id):
+        response = self.ec2.describe_security_groups(
+            Filters=[{
+                'Name': 'group-name',
+                'Values': ['default'],
+            }, {
+                'Name': 'vpc-id',
+                'Values': [vpc_id],
+            }],
+        )
         default_group = response['SecurityGroups'][0]
         self.ec2.modify_instance_attribute(InstanceId=node.id, Groups=[default_group['GroupId']])
+        print('Deleting temporary security group')
         response = self.ec2.delete_security_group(GroupId=group_id)
 
 
     def destroy_node(self, node, extra=None, **kwargs):
         if extra is not None:
-            self.delete_node_security_group(node, extra)
+            self.delete_node_security_group(node, extra['groupId'], extra['vpcId'])
 
         self.ec2.terminate_instances(InstanceIds=[node.id])
 
